==> familia_0.1.tar.gz: familia/src/file/view.cpp <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <iostream>
#include <string>
#include <sstream>
#include <vector>
#include <glibmm/ustring.h>

#include "view.h"
#include "position.h"
#include "boundary.h"

using namespace std;

FileView::_String& FileView::name() {
  return _name;
}

int& FileView::scale() {
  return _scale;
}

FileView::_Position& FileView::position() {
  return _position;
}

FileView::_Boundary& FileView::boundary() {
  return _boundary;
}

FileView::_Myt& FileView::parse(const _String what, const _String str) {
  if(what == "Name") {
    name() = str;
    clog << "Name: " << name() << endl;
  }
  else if(what == "Zoom") {
    istringstream ss(str);
    ss >> scale();
    clog << "Zoom: " << scale() << endl;
  }
  else if(what == "Position") {
    position().parse(str);
    clog << "x:" << position().get_x() << ", y:" << position().get_y() << endl;
  }
  else if(what == "BoundaryRect") {
    boundary().parse(str, ',');
    clog << "[" << boundary().get_x() << "," << boundary().get_y() << ","
	 << boundary().get_width() << "," << boundary().get_height() << "]" << endl;
  }
  else {
    cerr << "Unknown parameter for FileView: " << what << endl;
  }
  return (*this);
}

==> familia_0.1.2.tar.gz: familia/src/file/view.cpp <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <iostream>
#include <string>
#include <sstream>
#include <vector>
#include <glibmm/ustring.h>

#include "view.h"
#include "position.h"
#include "boundary.h"

using namespace std;

FileView::String& FileView::name() {
  return _name;
}

int FileView::scale() {
  return _scale;
}

FileView::_Position& FileView::position() {
  return _position;
}

FileView::_Boundary& FileView::boundary() {
  return _boundary;
}

FileView::_Myt& FileView::parse(const String what, const String str) {
  if(what == "Name") {
    name() = str;
    clog << "Name: " << name();
  }
  else if(what == "Zoom") {
    istringstream ss(str);
    ss >> _scale;
    clog << "Zoom: " << scale();
  }
  else if(what == "Position") {
    position().parse(str);
    clog << "x:" << position().get_x() << ", y:" << position().get_y();
  }
  else if(what == "BoundaryRect") {
    boundary().parse(str, ',');
    clog << "[" << boundary().get_x() << "," << boundary().get_y() << ","
	 << boundary().get_width() << "," << boundary().get_height() << "]\n";
  }
  return (*this);
}
